@@ -1,9 +1,9 @@
 from django.conf import settings
 from django.utils.functional import cached_property
-from django_extensions.db.models import TimeStampedModel, ActivatorModel
+from django_extensions.db.models import ActivatorModel, TimeStampedModel
 from firebase_admin import firestore
 
-from bitsoframework.middleware import get_user, _active
+from bitsoframework.middleware import _active, get_user
 from bitsoframework.utils import lists
 from bitsoframework.utils.booleans import to_boolean
 
