@@ -33,12 +33,18 @@ def calculate(media, type):
     if file:
         hash = getattr(hashlib, type)()
 
-        content = file.read()
+        file.seek(0)
 
-        hash.update(content)
+        while True:
+            content = file.read(65536)
+            if not content:
+                break
+            hash.update(content)
 
         digest = hash.hexdigest()
 
+        file.seek(0)
+
         return digest
 
     return None
