@@ -5,10 +5,10 @@ from django.contrib.contenttypes.fields import GenericForeignKey
 from django.contrib.contenttypes.models import ContentType
 from django.core.files.base import File
 from django.db import models
-from django.db.models import CASCADE
 from django.db.models.fields.files import FieldFile
 from django.utils.functional import cached_property
-from django_extensions.db.models import TimeStampedModel, TitleDescriptionModel, ActivatorModel
+from django_extensions.db.models import (ActivatorModel, TimeStampedModel,
+                                         TitleDescriptionModel)
 
 from bitsoframework.authored.models import AuthoredModel
 from bitsoframework.indexable.models import IndexedModel
@@ -17,7 +17,8 @@ from bitsoframework.utils import files
 from bitsoframework.utils.files import get_random_name
 from bitsoframework.utils.reflection import require
 
-ON_DELETE = getattr(settings, 'BITSO_MEDIA_ON_DELETE', CASCADE)
+AUTH_USER_MODEL = settings.AUTH_USER_MODEL
+ON_DELETE = require(f"django.db.models.{getattr(settings, 'BITSO_MEDIA_ON_DELETE', 'CASCADE')}")
 MEDIA_CATEGORY_CHOICES = getattr(settings, "BITSO_MEDIA_CATEGORY_CHOICES", None)
 MEDIA_PATH = getattr(settings, "BITSO_MEDIA_PATH", "uploads/documents")
 MEDIA_PATH_RESOLVER_CLASS = require(getattr(settings, "BITSO_MEDIA_PATH_RESOLVER",
@@ -34,9 +35,9 @@ class AbstractMedia(IndexedModel,
                     AuthoredModel):
     """
     Abstract class common to document and image models.
-    
+
     @since: 05/10/2016 19:50:00
-    
+
     @author: bitsoframework
     """
 
